@@ -8,3 +8,8 @@ class InvalidUUID(Exception):
 class InvalidEndpointProtocol(Exception):
     """Exception for invalid endpoint protocol."""
     pass
+
+
+class InvalidSurrogateID(Exception):
+    """Exception for invalid surrogate ID in message-type"""
+    pass
